@@ -7,6 +7,7 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use super::Client;
+use crate::client::utils::retry;
 use crate::client::{connections::QueryResult, errors::Error};
 use crate::messaging::{
     data::{DataQuery, ServiceMsg},
@@ -18,6 +19,7 @@ use tracing::debug;
 
 impl Client {
     // Send a Query to the network and await a response.
+    // Queries are automatically retried using exponential backoff if the timeout is hit
     // This function is a helper private to this module.
     pub(crate) async fn send_query(&self, query: DataQuery) -> Result<QueryResult, Error> {
         let client_pk = self.public_key();
@@ -25,10 +27,19 @@ impl Client {
         let serialised_query = WireMsg::serialize_msg_payload(&msg)?;
         let signature = self.keypair.sign(&serialised_query);
 
-        tokio::time::timeout(
-            self.query_timeout,
-            self.send_signed_query(query, client_pk, serialised_query, signature),
-        )
+        retry(|| async {
+            tokio::time::timeout(
+                self.query_timeout,
+                self.send_signed_query(
+                    query.clone(),
+                    client_pk,
+                    serialised_query.clone(),
+                    signature.clone(),
+                ),
+            )
+            .await
+            .map_err(backoff::Error::Transient)
+        })
         .await
         .map_err(|_| Error::NoResponse)?
     }
